@@ -1,14 +1,14 @@
 import click
-from click_default_group import DefaultGroup
 
+from task import database
 from task import utils
 
 
 @click.group(
     name='add',
-    cls=DefaultGroup,
+    cls=utils.AliasedGroup,
     default='new-task',
-    default_if_no_args=True
+    default_if_no_args=True,
 )
 def main():
     """Add task"""
@@ -19,11 +19,12 @@ def main():
 @click.option('-p', '--project', help="specyfiy project")
 @click.option('-u', '--urgency', help="urgency")
 @click.option('-d', '--due', help="due date")
-def new_task(task: str, project: str = None, urgency: int = 0, due: str = None):
+def new_task(
+    task: str, project: str = None, urgency: int = 0, due: str = None
+):
     """Add task to database."""
-    if utils.does_db_exist()[0] is False:
-        utils.create_db()
-
+    db = database.sql_init()
+    table = database.setup_todo_table(db)
     task_data = dict()
     task_data['task'] = task
     task_data['project'] = project
@@ -31,4 +32,5 @@ def new_task(task: str, project: str = None, urgency: int = 0, due: str = None):
     task_data['due'] = utils.parse_due(due)
     task_data['created_at'] = utils.format_current_time()
     task_data['updated_at'] = utils.format_current_time()
-    utils.insert_to_db(task_data)
+    task_id = database.insert_task(db, table, task_data)
+    utils.info(f"added task {task_id}")
