@@ -26,5 +26,8 @@ def task_done(task_id: int = 0) -> int:
     db = database.sql_init()
     table = database.setup_todo_table(db)
 
-    database.set_task_done(db, table, task_id)
-    utils.info(f"Done {task_id}")
+    ret = database.set_task_done(db, table, task_id)
+    if ret == 0:
+        utils.info(f"Done {task_id}")
+    else:
+        utils.error(f"Task {task_id} does not exist")
